---
title: <span class="badge object-type-scalar"></span> Kilometer
---
# <span class="badge object-type-scalar"></span> Kilometer

Length: kilometer (km)

## Definition

```python
# Length: kilometer (km)
Kilometer: typing.Literal["lengthkm"] = "lengthkm"
```
